from urllib.parse import urlparse, urlencode
import urllib.request
import os
from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from abc import ABC, abstractmethod


class Downloader(ABC):

    def __init__(self):
        pass

    @abstractmethod
    def download(self, url, post=None):
        pass

    def get_content(self, url, cache = None, post = None):
        if cache and os.path.exists(cache):
            print("Loading cache ({})".format(cache))
            with open(cache) as f:
                content = "\n".join(f.readlines())
        else:
            content = self.download(url, post)

            if cache:
                print("Saving cache ({})".format(cache))
                dir = os.path.dirname(cache)
                if dir != "" and not os.path.exists(dir):
                    os.makedirs(dir)
                with open(cache, "w") as text_file:
                    text_file.write(content)
        return content


class SimpleDownloader(Downloader):

    def __init__(self):
        super().__init__()


    def download(self, url, post=None):
        print("Downloading {}".format(url))

        try:
            if post:
                post_args = urlencode(post).encode()
                resource = urllib.request.urlopen(url, post_args)
            else:
                resource = urllib.request.urlopen(url)
            data = resource.read().decode(resource.headers.get_content_charset())
            return data
        except Exception as e:
            print(e)
            return None



class ChromiumHeadlessDownloader(Downloader):

    def __init__(self):
        super().__init__()
        self.options = Options()
        self.options.add_argument("--headless=new")
        self.options.add_argument("--disable-dev-shm-usage")
        self.options.add_argument("--no-sandbox")
        self.service = Service("/usr/bin/chromedriver")


    def download(self, url, post=None):
        if post:
            raise Exception('POST method with Chromium headless not yet implemented')
        print("Download {}".format(url))
        self.driver = webdriver.Chrome(service=self.service, options=self.options)

        self.driver.get(url)
        doc = self.driver.page_source
        self.driver.quit()
        return doc
